==> zio-aws-codecatalyst_2.12-7.21.15.1-sources.jar: zio/aws/codecatalyst/model/DeleteSourceRepositoryRequest.scala <==
package zio.aws.codecatalyst.model
import zio.aws.codecatalyst.model.primitives.{
  SourceRepositoryNameString,
  NameString
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteSourceRepositoryRequest(
    spaceName: NameString,
    projectName: NameString,
    name: SourceRepositoryNameString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest = {
    import DeleteSourceRepositoryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
      .builder()
      .spaceName(NameString.unwrap(spaceName): java.lang.String)
      .projectName(NameString.unwrap(projectName): java.lang.String)
      .name(SourceRepositoryNameString.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest.ReadOnly =
    zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest
      .wrap(buildAwsValue())
}
object DeleteSourceRepositoryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest =
      zio.aws.codecatalyst.model
        .DeleteSourceRepositoryRequest(spaceName, projectName, name)
    def spaceName: NameString
    def projectName: NameString
    def name: SourceRepositoryNameString
    def getSpaceName: ZIO[Any, Nothing, NameString] = ZIO.succeed(spaceName)
    def getProjectName: ZIO[Any, Nothing, NameString] = ZIO.succeed(projectName)
    def getName: ZIO[Any, Nothing, SourceRepositoryNameString] =
      ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
  ) extends zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest.ReadOnly {
    override val spaceName: NameString =
      zio.aws.codecatalyst.model.primitives.NameString(impl.spaceName())
    override val projectName: NameString =
      zio.aws.codecatalyst.model.primitives.NameString(impl.projectName())
    override val name: SourceRepositoryNameString =
      zio.aws.codecatalyst.model.primitives
        .SourceRepositoryNameString(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
  ): zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-codecatalyst_3-7.21.15.11-sources.jar: zio/aws/codecatalyst/model/DeleteSourceRepositoryRequest.scala <==
package zio.aws.codecatalyst.model
import zio.aws.codecatalyst.model.primitives.{
  SourceRepositoryNameString,
  NameString
}
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class DeleteSourceRepositoryRequest(
    spaceName: NameString,
    projectName: NameString,
    name: SourceRepositoryNameString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest = {
    import DeleteSourceRepositoryRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
      .builder()
      .spaceName(NameString.unwrap(spaceName): java.lang.String)
      .projectName(NameString.unwrap(projectName): java.lang.String)
      .name(SourceRepositoryNameString.unwrap(name): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest.ReadOnly =
    zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest
      .wrap(buildAwsValue())
}
object DeleteSourceRepositoryRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest =
      zio.aws.codecatalyst.model
        .DeleteSourceRepositoryRequest(spaceName, projectName, name)
    def spaceName: NameString
    def projectName: NameString
    def name: SourceRepositoryNameString
    def getSpaceName: ZIO[Any, Nothing, NameString] = ZIO.succeed(spaceName)
    def getProjectName: ZIO[Any, Nothing, NameString] = ZIO.succeed(projectName)
    def getName: ZIO[Any, Nothing, SourceRepositoryNameString] =
      ZIO.succeed(name)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
  ) extends zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest.ReadOnly {
    override val spaceName: NameString =
      zio.aws.codecatalyst.model.primitives.NameString(impl.spaceName())
    override val projectName: NameString =
      zio.aws.codecatalyst.model.primitives.NameString(impl.projectName())
    override val name: SourceRepositoryNameString =
      zio.aws.codecatalyst.model.primitives
        .SourceRepositoryNameString(impl.name())
  }
  def wrap(
      impl: software.amazon.awssdk.services.codecatalyst.model.DeleteSourceRepositoryRequest
  ): zio.aws.codecatalyst.model.DeleteSourceRepositoryRequest.ReadOnly =
    new Wrapper(impl)
}
